@@ -69,6 +69,14 @@ class Data:
                     "Synthetic": {"tij": [str(path + "data/Synthetic_Data/synthetic_tij.dat"), ","],
                                   "meta": [str(path + "data/Synthetic_Data/synthetic_metadata.dat"), ","],
                                   "attr": {0: "ID", 1: "type"}},
+                    "WS16": {"tij": [str(path + "data/WS16/tij_WS16.dat"), "\t"],
+                             "meta": [str(path + "data/WS16/metadata_WS16.dat"), "\t"],
+                             "attr": {0: "ID", 1: "Age", 2: "Sex", 3: "Country", 4: "Language", 5: "Education",
+                                      6: "Academic Background", 7: "Role", 8: "Previous participation"}},
+                    "ICCSS17": {"tij": [str(path + "data/ICCSS17/tij_ICCSS17.dat"), "\t"],
+                             "meta": [str(path + "data/WS16/metadata_ICCSS17.dat"), "\t"],
+                             "attr": {0: "ID", 1: "Age", 2: "Sex", 3: "Country", 4: "Language", 5: "Education",
+                                      6: "Academic Background", 7: "Role", 8: "Previous participation"}},
                     }
 
         if data_set_name is not None:
